@@ -8,7 +8,7 @@ import sys
 
 from plainbox.abc import IJobResult
 from plainbox.impl.applogic import get_whitelist_by_name
-from plainbox.impl.commands.checkbox import CheckBoxInvocationMixIn
+from plainbox.impl.commands.inv_checkbox import CheckBoxInvocationMixIn
 from plainbox.impl.depmgr import DependencyDuplicateError
 from plainbox.impl.exporter import ByteStringStreamTranslator
 from plainbox.impl.exporter import get_all_exporters
@@ -38,8 +38,8 @@ logger = getLogger("checkbox.ng.commands.oldcli")
 
 class CliInvocation(CheckBoxInvocationMixIn):
 
-    def __init__(self, provider_list, config, settings, ns, display=None):
-        super().__init__(provider_list, config)
+    def __init__(self, provider_loader, config, settings, ns, display=None):
+        super().__init__(provider_loader, config)
         self.settings = settings
         self.display = display
         self.ns = ns
@@ -318,8 +318,11 @@ class CliInvocation(CheckBoxInvocationMixIn):
                 result['outcome'] = choice
                 break
             elif choice == _('test'):
+                # NOTE: this can raise but oldcli is dead anyway
+                ctrl = runner._get_ctrl_for_job(job)
                 (result['return_code'],
-                 result['io_log_filename']) = runner._run_command(job, config)
+                 result['io_log_filename']) = runner._run_command(
+                     job, config, ctrl)
             elif choice == _('comments'):
                 result['comments'] = input(_('Please enter your comments:\n'))
         return DiskJobResult(result)
